# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class WebhookProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'url': 'str',
        'password': 'str',
        'username': 'str',
        'inbox_id': 'str',
        'user_id': 'str',
        'event_name': 'str',
        'updated_at': 'datetime',
        'created_at': 'datetime',
        'ai_transform_id': 'str',
        'health_status': 'str',
        'phone_number_id': 'str',
        'name': 'str',
        'id': 'str'
    }

    attribute_map = {
        'url': 'url',
        'password': 'password',
        'username': 'username',
        'inbox_id': 'inboxId',
        'user_id': 'userId',
        'event_name': 'eventName',
        'updated_at': 'updatedAt',
        'created_at': 'createdAt',
        'ai_transform_id': 'aiTransformId',
        'health_status': 'healthStatus',
        'phone_number_id': 'phoneNumberId',
        'name': 'name',
        'id': 'id'
    }

    def __init__(self, url=None, password=None, username=None, inbox_id=None, user_id=None, event_name=None, updated_at=None, created_at=None, ai_transform_id=None, health_status=None, phone_number_id=None, name=None, id=None, local_vars_configuration=None):  # noqa: E501
        """WebhookProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._url = None
        self._password = None
        self._username = None
        self._inbox_id = None
        self._user_id = None
        self._event_name = None
        self._updated_at = None
        self._created_at = None
        self._ai_transform_id = None
        self._health_status = None
        self._phone_number_id = None
        self._name = None
        self._id = None
        self.discriminator = None

        self.url = url
        if password is not None:
            self.password = password
        if username is not None:
            self.username = username
        if inbox_id is not None:
            self.inbox_id = inbox_id
        self.user_id = user_id
        if event_name is not None:
            self.event_name = event_name
        self.updated_at = updated_at
        self.created_at = created_at
        if ai_transform_id is not None:
            self.ai_transform_id = ai_transform_id
        if health_status is not None:
            self.health_status = health_status
        if phone_number_id is not None:
            self.phone_number_id = phone_number_id
        if name is not None:
            self.name = name
        self.id = id

    @property
    def url(self):
        """Gets the url of this WebhookProjection.  # noqa: E501


        :return: The url of this WebhookProjection.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this WebhookProjection.


        :param url: The url of this WebhookProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def password(self):
        """Gets the password of this WebhookProjection.  # noqa: E501


        :return: The password of this WebhookProjection.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this WebhookProjection.


        :param password: The password of this WebhookProjection.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def username(self):
        """Gets the username of this WebhookProjection.  # noqa: E501


        :return: The username of this WebhookProjection.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this WebhookProjection.


        :param username: The username of this WebhookProjection.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def inbox_id(self):
        """Gets the inbox_id of this WebhookProjection.  # noqa: E501


        :return: The inbox_id of this WebhookProjection.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this WebhookProjection.


        :param inbox_id: The inbox_id of this WebhookProjection.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def user_id(self):
        """Gets the user_id of this WebhookProjection.  # noqa: E501


        :return: The user_id of this WebhookProjection.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this WebhookProjection.


        :param user_id: The user_id of this WebhookProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def event_name(self):
        """Gets the event_name of this WebhookProjection.  # noqa: E501


        :return: The event_name of this WebhookProjection.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this WebhookProjection.


        :param event_name: The event_name of this WebhookProjection.  # noqa: E501
        :type: str
        """
        allowed_values = ["EMAIL_RECEIVED", "NEW_EMAIL", "NEW_CONTACT", "NEW_ATTACHMENT", "EMAIL_OPENED", "EMAIL_READ", "DELIVERY_STATUS", "BOUNCE", "BOUNCE_RECIPIENT", "NEW_SMS", "NEW_GUEST_USER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_name not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_name` ({0}), must be one of {1}"  # noqa: E501
                .format(event_name, allowed_values)
            )

        self._event_name = event_name

    @property
    def updated_at(self):
        """Gets the updated_at of this WebhookProjection.  # noqa: E501


        :return: The updated_at of this WebhookProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this WebhookProjection.


        :param updated_at: The updated_at of this WebhookProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this WebhookProjection.  # noqa: E501


        :return: The created_at of this WebhookProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this WebhookProjection.


        :param created_at: The created_at of this WebhookProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def ai_transform_id(self):
        """Gets the ai_transform_id of this WebhookProjection.  # noqa: E501


        :return: The ai_transform_id of this WebhookProjection.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_id

    @ai_transform_id.setter
    def ai_transform_id(self, ai_transform_id):
        """Sets the ai_transform_id of this WebhookProjection.


        :param ai_transform_id: The ai_transform_id of this WebhookProjection.  # noqa: E501
        :type: str
        """

        self._ai_transform_id = ai_transform_id

    @property
    def health_status(self):
        """Gets the health_status of this WebhookProjection.  # noqa: E501


        :return: The health_status of this WebhookProjection.  # noqa: E501
        :rtype: str
        """
        return self._health_status

    @health_status.setter
    def health_status(self, health_status):
        """Sets the health_status of this WebhookProjection.


        :param health_status: The health_status of this WebhookProjection.  # noqa: E501
        :type: str
        """
        allowed_values = ["HEALTHY", "UNHEALTHY"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and health_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `health_status` ({0}), must be one of {1}"  # noqa: E501
                .format(health_status, allowed_values)
            )

        self._health_status = health_status

    @property
    def phone_number_id(self):
        """Gets the phone_number_id of this WebhookProjection.  # noqa: E501


        :return: The phone_number_id of this WebhookProjection.  # noqa: E501
        :rtype: str
        """
        return self._phone_number_id

    @phone_number_id.setter
    def phone_number_id(self, phone_number_id):
        """Sets the phone_number_id of this WebhookProjection.


        :param phone_number_id: The phone_number_id of this WebhookProjection.  # noqa: E501
        :type: str
        """

        self._phone_number_id = phone_number_id

    @property
    def name(self):
        """Gets the name of this WebhookProjection.  # noqa: E501


        :return: The name of this WebhookProjection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WebhookProjection.


        :param name: The name of this WebhookProjection.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this WebhookProjection.  # noqa: E501


        :return: The id of this WebhookProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WebhookProjection.


        :param id: The id of this WebhookProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookProjection):
            return True

        return self.to_dict() != other.to_dict()
